@@ -1,3 +1,4 @@
+use core::fmt;
 use std::{collections::HashMap, path::PathBuf};
 
 use serde_derive::Serialize;
@@ -98,6 +99,13 @@ impl InterfaceElement {
     }
 }
 
+#[derive(Serialize, Clone, Debug, PartialEq)]
+pub enum ItemKind {
+    Interface,
+    Parcelable,
+    Enum,
+}
+
 #[derive(Serialize, Clone, Debug, PartialEq)]
 pub enum Item {
     Interface(Interface),
@@ -106,6 +114,14 @@ pub enum Item {
 }
 
 impl Item {
+    pub fn get_kind(&self) -> ItemKind {
+        match self {
+            Item::Interface(_) => ItemKind::Interface,
+            Item::Parcelable(_) => ItemKind::Parcelable,
+            Item::Enum(_) => ItemKind::Enum,
+        }
+    }
+
     pub fn get_name(&self) -> &str {
         match self {
             Item::Interface(i) => &i.name,
@@ -210,9 +226,9 @@ pub struct Arg {
 
 #[derive(Serialize, Clone, Debug, PartialEq)]
 pub enum Direction {
-    In,
-    Out,
-    InOut,
+    In(Range),
+    Out(Range),
+    InOut(Range),
     Unspecified,
 }
 
@@ -222,6 +238,17 @@ impl Default for Direction {
     }
 }
 
+impl fmt::Display for Direction {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            Direction::In(_) => write!(f, "in"),
+            Direction::Out(_) => write!(f, "out"),
+            Direction::InOut(_) => write!(f, "inout"),
+            Direction::Unspecified => Ok(()),
+        }
+    }
+}
+
 #[derive(Serialize, Clone, Debug, PartialEq)]
 pub struct Member {
     pub name: String,
@@ -321,7 +348,7 @@ impl Type {
     ) -> Self {
         Type {
             name: "Map".to_owned(),
-            kind: TypeKind::List,
+            kind: TypeKind::Map,
             generic_types: Vec::from([key_param, value_param]),
             definition: None,
             symbol_range: Range::new(lookup, start, end),
